.. $Id: todo.rst 1515 2014-03-11 06:05:15Z jemian $

.. _todo:

==========
TO-DO List
==========

* move this list to the **TRAC** site:
  https://subversion.xray.aps.anl.gov/trac/bcdaext/wiki/SpecDomain
* add support to document SPEC array declarations
* improve the display of directives for variables and macros
* make the Index look better
* provide links from each macro to its source code
* provide for the directive options indicated in the source code
* resolve the items marked *FIXME:* in the source code
* resolve the items marked *TODO:* in the source code
* identify and document undeclared variables in the global scope
* support the :summary: role to explicitly declare a summary
* cdef argument list not handled yet 
* Option to index all symbols in a macro file
* allow section headings inside macro declaration docstrings
* create a role (or example using a ref) to refer to a macro file from the documentation
* produce a custom module index with links and summary lines
